import { createRouter, createWebHistory } from 'vue-router'
import { get } from 'lodash-es'
import { UserStore } from '@/store/user'
import { isInCenter, hasCenterRoutes } from './modules/center'
import axios from 'axios'
const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      redirect: '/home'
    },
    {
      path: '/home',
      name: 'home',
      meta: { title: '产学研用协同创新数字化平台', keepAlive: true },
      component: () => import('@/views/home/index.vue')
    },
    {
      path: '/screen',
      name: 'screen',
      meta: { title: '产学研用协同创新数字化平台', keepAlive: true },
      component: () => import('@/views/screen/index.vue')
    }
  ]
})
const getRedirectUri = (route) => {
  return route.path
}
const centerRoutePagePath = '/info/loading'
router.beforeEach(async (to, from, next) => {
  const userStore = UserStore()
  document.title = get(to, 'meta.title', '产学研用协同创新数字化平台')
  const routeCheck = isInCenter(to)
  // 进入个人中心,检查是否有token,没有token直接返回login
  let token = localStorage.getItem('webToken')
  if (!token) token = localStorage.getItem('token')
  if (token) {
    const res = await axios.request({
      method: 'get',
      url: `${import.meta.env.VITE_APP_BASE_API}/token/tokenView`,
      responseType: 'json',
      headers: {
        token: token
      }
    })
    if (res.data.errcode === 0) userStore.setUser(res.data.data)
    if (!routeCheck) {
      // 没有进入个人中心,直接放行
      next()
      return
    }
    //个人中心处理
    const isReg = hasCenterRoutes(router, to)
    // 返回结果是undefined,不需要处理,直接next
    if (!isReg) {
      // 返回false,是需要注册路由,跳转进入路由页面
      const menus = userStore.menus
      if (menus && menus.length > 0) {
        // 已注册完路由,但是没有当前路由信息,回到基础信息
        next({ path: '/center/basic' })
        return
      }
      next({ path: centerRoutePagePath, query: { redirectPath: getRedirectUri(to) } })
    } else {
      let redirectPath = get(to, 'query.redirectPath')
      if (redirectPath) next(redirectPath)
      else next()
      return
    }
  } else {
    if (!routeCheck) {
      // 没有进入个人中心,直接放行
      next()
      return
    }
    next('/login?status=1')
  }
})
router.afterEach(() => {
  window.scrollTo(0, 0)
})
export default router
