import { defineStore } from 'pinia'
import { AxiosWrapper } from '@/utils/axios-wrapper'
import { get } from 'lodash-es'
const url = '/matchExt'
const axios = new AxiosWrapper()

export const MatchExtStore = defineStore('matchExt', () => {
  const query = async ({ skip = 0, limit = undefined, ...info } = {}) => {
    let cond = {}
    if (skip) cond.skip = skip
    if (limit) cond.limit = limit
    cond = { ...cond, ...info }
    const res = await axios.$get(`${url}`, cond)
    return res
  }
  const fetch = async (payload) => {
    const res = await axios.$get(`${url}/${payload}`)
    return res
  }
  const create = async (payload) => {
    const res = await axios.$post(`${url}`, payload)
    return res
  }
  const update = async (payload) => {
    const id = get(payload, 'id', get(payload, '_id'))
    const res = await axios.$post(`${url}/${id}`, payload)
    return res
  }
  const del = async (payload) => {
    const res = await axios.$delete(`${url}/${payload}`)
    return res
  }
  const firstStep = async (payload) => {
    const id = get(payload, 'id', get(payload, '_id'))
    const res = await axios.$post(`${url}/firstStep/${id}`, payload)
    return res
  }
  const step1 = async (payload) => {
    const res = await axios.$post(`${url}/step1`, payload)
    return res
  }
  const step2 = async (payload) => {
    const res = await axios.$post(`${url}/step2`, payload)
    return res
  }
  const stepFill = async (payload) => {
    const res = await axios.$post(`${url}/step2/fill`, payload)
    return res
  }
  const step3 = async (payload) => {
    const res = await axios.$post(`${url}/step3`, payload)
    return res
  }
  const step4 = async (payload) => {
    const res = await axios.$post(`${url}/step4`, payload)
    return res
  }
  const step4Score = async (payload) => {
    const id = get(payload, 'id', get(payload, '_id'))
    const res = await axios.$post(`${url}/step4/score/${id}`, payload)
    return res
  }
  const step4To5 = async (payload) => {
    const id = get(payload, 'id', get(payload, '_id'))
    const res = await axios.$post(`${url}/step4/to5/${id}`, payload)
    return res
  }
  const step5 = async (payload) => {
    const res = await axios.$post(`${url}/step5`, payload)
    return res
  }
  const step5Time = async (payload) => {
    const id = get(payload, 'id', get(payload, '_id'))
    const res = await axios.$post(`${url}/step5/time/${id}`, payload)
    return res
  }
  const step5Sms = async (payload) => {
    const res = await axios.$get(`${url}/step5/sms/${payload}`)
    return res
  }
  const step5Sup = async (payload) => {
    const id = get(payload, 'id', get(payload, '_id'))
    const res = await axios.$post(`${url}/step5/supplement/${id}`, payload)
    return res
  }
  const step5Order = async (payload) => {
    const id = get(payload, 'match_id', get(payload, 'match_id'))
    const res = await axios.$post(`${url}/step5/order/${id}`, payload)
    return res
  }
  const step5Name = async (payload) => {
    const id = get(payload, 'match_id', get(payload, 'match_id'))
    const res = await axios.$get(`${url}/step5/list/${id}`, payload)
    return res
  }
  const step6 = async (payload) => {
    const res = await axios.$post(`${url}/step6`, payload)
    return res
  }
  const step7 = async (payload) => {
    const res = await axios.$post(`${url}/step7`, payload)
    return res
  }
  const step7Score = async (payload) => {
    const id = get(payload, 'match_id', get(payload, 'match_id'))
    const res = await axios.$post(`${url}/step7/score/${id}`, payload)
    return res
  }
  const step8 = async (payload) => {
    const res = await axios.$post(`${url}/step8`, payload)
    return res
  }
  const lastList = async (payload) => {
    const res = await axios.$post(`${url}/lastList/${payload}`)
    return res
  }
  return {
    query,
    fetch,
    create,
    update,
    firstStep,
    step1,
    step2,
    stepFill,
    step3,
    step4,
    step4Score,
    step4To5,
    step5,
    step5Time,
    step5Sms,
    step5Sup,
    step5Order,
    step5Name,
    step6,
    step7,
    step7Score,
    step8,
    lastList,
    del
  }
})
